==> haskell-mockery-0.3.5-703-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-ENxoLngQfKS3GZva6Uchzi
key:                  mockery-0.3.5-ENxoLngQfKS3GZva6Uchzi
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  b93e1cb0e92212d3c6d1d43b9b47688e
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-ENxoLngQfKS3GZva6Uchzi
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-4E32BcIZr1L3jlGspPlsRU
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-718-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-Cwc5TtVTAlfJ8Oo82wWz8X
key:                  mockery-0.3.5-Cwc5TtVTAlfJ8Oo82wWz8X
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  7aebb5456487904370887d2fe33040d1
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-Cwc5TtVTAlfJ8Oo82wWz8X
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-3Kz0rP5ynAxBw1QPVmQ3gj
    temporary-1.3-FQWpMYFFv2g2HCDcFkOPeW

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
